Extending yt
============

yt has been designed to be flexible, with several entry points.

.. toctree::
   :maxdepth: 2

   writing_scripts
   using_the_interpreter
   plugin_file
   creating_datatypes
   creating_derived_quantities
   creating_derived_fields
   analyzing_in_parallel
